---
template: mainpanel
source_form: markdown
name: Trello Cardlist Backlog: Website, docs, etc
updated: October 2016
title: Trello Cardlist Backlog: Website, docs, etc
---
### Backlog: Website, docs, etc

* 232\. Would be nice to have a prettier website
* 233\. Some sort of Logo would be nice
* 58\. Blog Post: Pyxie Decisions #website
* 60\. Start thoughts on pyxie-gui #reflect
* 30\. Should we allow comments on website? #website
* 50\. Link current test programs on the website, maybe #website
